# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project uses date-based versioning.

<!-- scriv-insert-here -->

<a id='changelog-2025.3.31'></a>
## [2025.3.31] - 2025-03-31

### Added

- Add the mitol-django-scim app

- Added a minimum version for pyparsing.
